@@ -2,17 +2,17 @@
   filterthunderbird.h  -  Thunderbird mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILIMPORTER_FILTER_THUNDERBIRD_H
-#define MAILIMPORTER_FILTER_THUNDERBIRD_H
+#pragma once
 
 #include "filters.h"
 
-namespace MailImporter {
+namespace MailImporter
+{
 /**
  * Imports Thunderbird mail folder recursively, keeping the folder structure.
  * @author Danny Kukawka
@@ -35,6 +35,7 @@ public:
 protected:
     Q_REQUIRED_RESULT virtual QString defaultInstallFolder() const;
     Q_REQUIRED_RESULT virtual QString settingsPath();
+
 private:
     void importDirContents(const QString &, const QString &, const QString &);
     void importMBox(const QString &, const QString &, const QString &);
@@ -42,4 +43,3 @@ private:
 };
 }
 
-#endif
